#[non_exhaustive]pub struct CsrExtensions {
pub key_usage: Option<KeyUsage>,
pub subject_information_access: Option<Vec<AccessDescription>>,
}Expand description
Describes the certificate extensions to be added to the certificate signing request (CSR).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_usage: Option<KeyUsage>Indicates the purpose of the certificate and of the key contained in the certificate.
subject_information_access: Option<Vec<AccessDescription>>For CA certificates, provides a path to additional information pertaining to the CA, such as revocation and policy. For more information, see Subject Information Access in RFC 5280.
Implementations
Sourceimpl CsrExtensions
impl CsrExtensions
Sourcepub fn key_usage(&self) -> Option<&KeyUsage>
pub fn key_usage(&self) -> Option<&KeyUsage>
Indicates the purpose of the certificate and of the key contained in the certificate.
Sourcepub fn subject_information_access(&self) -> &[AccessDescription]
pub fn subject_information_access(&self) -> &[AccessDescription]
For CA certificates, provides a path to additional information pertaining to the CA, such as revocation and policy. For more information, see Subject Information Access in RFC 5280.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subject_information_access.is_none().
Sourceimpl CsrExtensions
impl CsrExtensions
Sourcepub fn builder() -> CsrExtensionsBuilder
pub fn builder() -> CsrExtensionsBuilder
Creates a new builder-style object to manufacture CsrExtensions.