#[non_exhaustive]pub struct CustomAttribute {
pub object_identifier: String,
pub value: String,
}Expand description
Defines the X.500 relative distinguished name (RDN).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.object_identifier: StringSpecifies the object identifier (OID) of the attribute type of the relative distinguished name (RDN).
value: StringSpecifies the attribute value of relative distinguished name (RDN).
Implementations
Sourceimpl CustomAttribute
impl CustomAttribute
Sourcepub fn builder() -> CustomAttributeBuilder
pub fn builder() -> CustomAttributeBuilder
Creates a new builder-style object to manufacture CustomAttribute.