#[non_exhaustive]pub struct ExtendedKeyUsage {
pub extended_key_usage_type: Option<ExtendedKeyUsageType>,
pub extended_key_usage_object_identifier: Option<String>,
}Expand description
Specifies additional purposes for which the certified public key may be used other than basic purposes indicated in the KeyUsage extension.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.extended_key_usage_type: Option<ExtendedKeyUsageType>Specifies a standard ExtendedKeyUsage as defined as in RFC 5280.
extended_key_usage_object_identifier: Option<String>Specifies a custom ExtendedKeyUsage with an object identifier (OID).
Implementations
Sourceimpl ExtendedKeyUsage
impl ExtendedKeyUsage
Sourcepub fn extended_key_usage_type(&self) -> Option<&ExtendedKeyUsageType>
pub fn extended_key_usage_type(&self) -> Option<&ExtendedKeyUsageType>
Specifies a standard ExtendedKeyUsage as defined as in RFC 5280.
Sourcepub fn extended_key_usage_object_identifier(&self) -> Option<&str>
pub fn extended_key_usage_object_identifier(&self) -> Option<&str>
Specifies a custom ExtendedKeyUsage with an object identifier (OID).
Sourceimpl ExtendedKeyUsage
impl ExtendedKeyUsage
Sourcepub fn builder() -> ExtendedKeyUsageBuilder
pub fn builder() -> ExtendedKeyUsageBuilder
Creates a new builder-style object to manufacture ExtendedKeyUsage.