#[non_exhaustive]pub struct GeneralName {
pub other_name: Option<OtherName>,
pub rfc822_name: Option<String>,
pub dns_name: Option<String>,
pub directory_name: Option<Asn1Subject>,
pub edi_party_name: Option<EdiPartyName>,
pub uniform_resource_identifier: Option<String>,
pub ip_address: Option<String>,
pub registered_id: Option<String>,
}Expand description
Describes an ASN.1 X.400 GeneralName as defined in RFC 5280. Only one of the following naming options should be provided. Providing more than one option results in an InvalidArgsException error.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.other_name: Option<OtherName>Represents GeneralName using an OtherName object.
rfc822_name: Option<String>Represents GeneralName as an RFC 822 email address.
dns_name: Option<String>Represents GeneralName as a DNS name.
directory_name: Option<Asn1Subject>Contains information about the certificate subject. The Subject field in the certificate identifies the entity that owns or controls the public key in the certificate. The entity can be a user, computer, device, or service. The Subject must contain an X.500 distinguished name (DN). A DN is a sequence of relative distinguished names (RDNs). The RDNs are separated by commas in the certificate.
edi_party_name: Option<EdiPartyName>Represents GeneralName as an EdiPartyName object.
uniform_resource_identifier: Option<String>Represents GeneralName as a URI.
ip_address: Option<String>Represents GeneralName as an IPv4 or IPv6 address.
registered_id: Option<String>Represents GeneralName as an object identifier (OID).
Implementations
Sourceimpl GeneralName
impl GeneralName
Sourcepub fn other_name(&self) -> Option<&OtherName>
pub fn other_name(&self) -> Option<&OtherName>
Represents GeneralName using an OtherName object.
Sourcepub fn rfc822_name(&self) -> Option<&str>
pub fn rfc822_name(&self) -> Option<&str>
Represents GeneralName as an RFC 822 email address.
Sourcepub fn directory_name(&self) -> Option<&Asn1Subject>
pub fn directory_name(&self) -> Option<&Asn1Subject>
Contains information about the certificate subject. The Subject field in the certificate identifies the entity that owns or controls the public key in the certificate. The entity can be a user, computer, device, or service. The Subject must contain an X.500 distinguished name (DN). A DN is a sequence of relative distinguished names (RDNs). The RDNs are separated by commas in the certificate.
Sourcepub fn edi_party_name(&self) -> Option<&EdiPartyName>
pub fn edi_party_name(&self) -> Option<&EdiPartyName>
Represents GeneralName as an EdiPartyName object.
Sourcepub fn uniform_resource_identifier(&self) -> Option<&str>
pub fn uniform_resource_identifier(&self) -> Option<&str>
Represents GeneralName as a URI.
Sourcepub fn ip_address(&self) -> Option<&str>
pub fn ip_address(&self) -> Option<&str>
Represents GeneralName as an IPv4 or IPv6 address.
Sourcepub fn registered_id(&self) -> Option<&str>
pub fn registered_id(&self) -> Option<&str>
Represents GeneralName as an object identifier (OID).
Sourceimpl GeneralName
impl GeneralName
Sourcepub fn builder() -> GeneralNameBuilder
pub fn builder() -> GeneralNameBuilder
Creates a new builder-style object to manufacture GeneralName.