#[non_exhaustive]pub struct RevocationConfiguration {
pub crl_configuration: Option<CrlConfiguration>,
pub ocsp_configuration: Option<OcspConfiguration>,
}Expand description
Certificate revocation information used by the CreateCertificateAuthority and UpdateCertificateAuthority actions. Your private certificate authority (CA) can configure Online Certificate Status Protocol (OCSP) support and/or maintain a certificate revocation list (CRL). OCSP returns validation information about certificates as requested by clients, and a CRL contains an updated list of certificates revoked by your CA. For more information, see RevokeCertificate and Setting up a certificate revocation method in the Amazon Web Services Private Certificate Authority User Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crl_configuration: Option<CrlConfiguration>Configuration of the certificate revocation list (CRL), if any, maintained by your private CA. A CRL is typically updated approximately 30 minutes after a certificate is revoked. If for any reason a CRL update fails, Amazon Web Services Private CA makes further attempts every 15 minutes.
ocsp_configuration: Option<OcspConfiguration>Configuration of Online Certificate Status Protocol (OCSP) support, if any, maintained by your private CA. When you revoke a certificate, OCSP responses may take up to 60 minutes to reflect the new status.
Implementations
Sourceimpl RevocationConfiguration
impl RevocationConfiguration
Sourcepub fn crl_configuration(&self) -> Option<&CrlConfiguration>
pub fn crl_configuration(&self) -> Option<&CrlConfiguration>
Configuration of the certificate revocation list (CRL), if any, maintained by your private CA. A CRL is typically updated approximately 30 minutes after a certificate is revoked. If for any reason a CRL update fails, Amazon Web Services Private CA makes further attempts every 15 minutes.
Sourcepub fn ocsp_configuration(&self) -> Option<&OcspConfiguration>
pub fn ocsp_configuration(&self) -> Option<&OcspConfiguration>
Configuration of Online Certificate Status Protocol (OCSP) support, if any, maintained by your private CA. When you revoke a certificate, OCSP responses may take up to 60 minutes to reflect the new status.
Sourceimpl RevocationConfiguration
impl RevocationConfiguration
Sourcepub fn builder() -> RevocationConfigurationBuilder
pub fn builder() -> RevocationConfigurationBuilder
Creates a new builder-style object to manufacture RevocationConfiguration.